---
title: <span class="badge object-type-scalar"></span> KiloVoltAmpere
---
# <span class="badge object-type-scalar"></span> KiloVoltAmpere

Energy: Kilovolt-Ampere (kVA)

## Definition

```python
# Energy: Kilovolt-Ampere (kVA)
KiloVoltAmpere: typing.Literal["kvoltamp"] = "kvoltamp"
```
